@@ -1,6 +1,9 @@
 package Regexp::Parser;
 
-$VERSION = '0.20_01';
+use strict;
+use warnings;
+
+our $VERSION = '0.21_01';
 
 use 5.006;
 use Carp qw( carp croak );
@@ -307,8 +310,6 @@ sub del_handler {
 
 __END__
 
-=cut
-
 =head1 NAME
 
 Regexp::Parser - base class for parsing regexes
